@@ -28,6 +28,12 @@
 #include <QAbstractKineticScroller>
 #endif
 
+//test
+#include <QDBusMessage>
+#include <QDBusConnection>
+#include <QDBusInterface>
+//
+
 #define STATE_SPACE 0
 #define STATE_SYM 1
 #define STATE_WORD 2
@@ -53,7 +59,9 @@ TextProcessor::TextProcessor(QWidget *parent) :
     ui->setupUi(this);
     m_sMessage = NULL;
     m_recipient = ui->recipientWidget;
+
     connect(m_recipient->m_btSend,SIGNAL(clicked()),this,SLOT(sendSms()));
+
     m_smsEdit = ui->textEdit;
     m_phoneNumber = m_recipient->getPhoneNumberField();
 
@@ -109,6 +117,20 @@ TextProcessor::TextProcessor(QWidget *parent) :
     }
 }
 
+void TextProcessor::setStandalone(bool bStandalone)
+{
+    m_bStandalone = bStandalone;
+
+    if(!m_bStandalone)
+    {
+        m_recipient->hide();
+    }
+    else
+    {
+        m_recipient->show();
+    }
+}
+
 void TextProcessor::setDictionary(dictionary *dict)
 {
     m_dict = dict;
@@ -121,7 +143,7 @@ void TextProcessor::processInput(QString sInput,Core::Keyboards sKeyboard)
         bFocusPhoneNumber = true;
 
     if(!bFocusPhoneNumber)
-    {            
+    {
         m_smsEdit->setFocus();
         if(sKeyboard == Core::Qwerty)
             processQwerty(sInput);
@@ -135,7 +157,7 @@ void TextProcessor::processInput(QString sInput,Core::Keyboards sKeyboard)
     {
         if(sInput.compare(Keyboard::DELETE) == 0)
             m_phoneNumber->backspace();
-        else
+        else if(sInput.length() == 1 && sInput.compare("\n") != 0)
             m_phoneNumber->insert(sInput);
     }
 }
@@ -727,3 +749,77 @@ void TextProcessor::alarmNewChar()
     m_bTimerNewChar = true;
 }
 
+/** Set text in textEdit **/
+void TextProcessor::setText(QString sWord)
+{
+    if(!m_bQwertyEnable)
+        m_smsEdit->disconnect();
+
+    m_cursorSmsText.select(QTextCursor::Document);
+    m_cursorSmsText.removeSelectedText();
+    m_cursorSmsText.insertText(sWord);
+
+    if(!m_bQwertyEnable)
+    {
+        connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
+        connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
+        cursorPosChanged();
+    }
+}
+
+/** Return text from textEdit**/
+QString TextProcessor::getText()
+{
+    return m_smsEdit->toPlainText().toUtf8();
+}
+
+/** Return btSend **/
+QPushButton* TextProcessor::getSendBt()
+{
+    return m_recipient->m_btSend;
+}
+
+/** Commit text to external app**/
+void TextProcessor::commit()
+{
+     parentWidget()->parentWidget()->hide();
+
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+            "it.rsc.fastsms.plugin.connection", // --dest
+            "/", // destination object path
+            "it.rsc.fastsms.plugin.connection",
+            "requestCommit"
+            );
+
+    //msg << "test";
+    QList<QVariant> args;
+    args.append(m_smsEdit->toPlainText());
+    msg.setArguments(args);
+    msg = QDBusConnection::sessionBus().call(msg);
+    qDebug() << msg;
+    bool ok = msg.type() != QDBusMessage::ErrorMessage;
+
+    //Reset fastwrite state
+    if(!m_bQwertyEnable)
+        m_smsEdit->disconnect();
+
+    m_nState = STATE_SEND;
+    m_smsEdit->clear();
+    m_sCompleteValue.clear();
+    //m_phoneNumber->clear();
+    m_lWord.clear();
+    m_nWordIndex=0;
+
+    //update char and sms count
+    updateCharCounter(ACTION_SEND);
+    //
+
+    if(!m_bQwertyEnable)
+    {
+        connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
+        connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
+        //Reset FastWrite status
+        processAlfanumeric(Keyboard::DELETE);
+    }
+}
+
