@@ -45,6 +45,12 @@ public:
     Recipient *m_recipient;
     void enableNewWordLayout();
     void addNewWord(QString *sWord);
+    void setText(QString sWord);
+    QString getText();
+    //Test
+    QPushButton *getSendBt();
+    void setStandalone(bool bStandalone = true);
+
 
 private:
     dictionary *m_dict;
@@ -83,16 +89,19 @@ private:
     QString *m_sMessage;
     int m_nSavedStyle;
     bool m_bQwertyEnable;
+    bool m_bStandalone;
 
 public slots:
     void processInput(QString, Core::Keyboards);
     void settingsChanged(int);
     void sendSms();
+    void commit();
 
 private slots:
     void alarmNewChar();
     void cursorPosChanged();
     void smsChanged();
+
 };
 
 #endif // TEXTPROCESSOR_H
